moFillTypesConfig = {};

function moFillTypesConfig:defaultValues()
	moFillTypes.values = {bestPrice={}, amount={}, totalAmount={}, greatDemand={}, fillTypes={}, noFillType={}, defaultNoFillType={}, loadDefaultNoFillTypes=true, loadNoFillTypes=true, name=true, regName=false, index=false, sortBy="Name", viewBy="Name"};
	moFillTypes.values.defaultNoFillType = {"UNKNOWN", "AIR", "POPLAR", "WEED",  "FUEL", "FERTILIZER", "HERBICIDE", "ROUNDBALE_WHEAT", "ROUNDBALE_GRASS", "ROUNDBALE_DRYGRASS", "ROUNDBALE_BARLEY", "SQUAREBALE_WHEAT", "SQUAREBALE_BARLEY", "TARP", "DRYGRASS", "GRASS", "DEF", "TREESAPLINGS"};		
	moFillTypes.values.noFillType = moFillTypes.values.defaultNoFillType;
end;

function moFillTypesConfig.loadXml(Xml, xmlNameTag, directory, typ) --loadConfig Callback
	if typ ~= "profilSettings" then return;end;	
	if moFillTypes.values == nil then moFillTypesConfig:defaultValues();end;	
	----------------------------------------------------------------------------------------------
	local groupNameTag = (xmlNameTag.. ".module.fillTypes(%d)"):format(0);	
	if getXMLBool(Xml, groupNameTag.. "#loadNoFillTypes") ~= nil then
		moFillTypes.values.loadNoFillTypes = getXMLBool(Xml, groupNameTag.. "#loadNoFillTypes");
	else
		return; --first config not found
	end;
	if getXMLBool(Xml, groupNameTag.. "#loadDefaultNoFillTypes") ~= nil then
		moFillTypes.values.loadDefaultNoFillTypes = getXMLBool(Xml, groupNameTag.. "#loadDefaultNoFillTypes");
	end;
	if getXMLBool(Xml, groupNameTag.. "#seeName") ~= nil then
		moFillTypes.values.name = getXMLBool(Xml, groupNameTag.. "#seeName");
	end;
	if getXMLBool(Xml, groupNameTag.. "#seeRegName") ~= nil then
		moFillTypes.values.regName = getXMLBool(Xml, groupNameTag.. "#seeRegName");
	end;
	if getXMLBool(Xml, groupNameTag.. "#seeIndex") ~= nil then
		moFillTypes.values.index = getXMLBool(Xml, groupNameTag.. "#seeIndex");
	end;	
	----------------------------------------------------------------------------------------------
	if moFillTypes.values.loadDefaultNoFillTypes then
		groupNameTag = (xmlNameTag.. ".module.fillTypes.defaultDeactivated");
		if getXMLString(Xml, groupNameTag.. "#name") then
			local defaultNoFillType = getXMLString(Xml, groupNameTag.. "#name");
			if string.len(defaultNoFillType) > 0 then
				local stringTable, isOkay = MultiOverlayV4:get_hl("stringSplit", {defaultNoFillType, ","}, "defaultNoFillType configFile XML/String Split");
				if isOkay then
					moFillTypes.values.defaultNoFillType = {};
					for a=1, #stringTable do
						table.insert(moFillTypes.values.defaultNoFillType, stringTable[a]);
					end;
				end;
			else
				moFillTypes.values.defaultNoFillType = {};
			end;
		end;
	end;
	----------------------------------------------------------------------------------------------
	if moFillTypes.values.loadNoFillTypes then
		groupNameTag = (xmlNameTag.. ".module.fillTypes.deactivated");
		if getXMLString(Xml, groupNameTag.. "#name") then
			local noFillType = getXMLString(Xml, groupNameTag.. "#name");
			if string.len(noFillType) > 0 then
				local stringTable, isOkay = MultiOverlayV4:get_hl("stringSplit", {noFillType, ","}, "noFillType configFile XML/String Split");
				if isOkay then
					moFillTypes.values.noFillType = {};
					for a=1, #stringTable do
						table.insert(moFillTypes.values.noFillType, stringTable[a]);
					end;
				end;
			else
				moFillTypes.values.noFillType = {};
			end;
		end;
	else
		moFillTypes.values.noFillType = {};
	end;
	----------------------------------------------------------------------------------------------
	if moFillTypes.values.loadDefaultNoFillTypes then
		if #moFillTypes.values.defaultNoFillType > 0 and #moFillTypes.values.noFillType > 0 then
			for index, name in pairs (moFillTypes.values.defaultNoFillType) do
				if name ~= nil then
					if moFillTypes.values.noFillType[name] == nil then			
						table.insert(moFillTypes.values.noFillType, name);
					end;
				end;
			end;
		else
			moFillTypes.values.noFillType = moFillTypes.values.defaultNoFillType;
		end;
	end;
	----------------------------------------------------------------------------------------------
end;

function moFillTypesConfig.saveXml(Xml, xmlNameTag, directory, typ) --saveConfig Callback
	if typ ~= "profilSettings" then return;end;
	if moFillTypes.values == nil then moFillTypesConfig:defaultValues();end;	
	----------------------------------------------------------------------------------------------
	local groupNameTag = (xmlNameTag.. ".module.fillTypes(%d)"):format(0);	
	setXMLBool(Xml, groupNameTag.. "#loadNoFillTypes", moFillTypes.values.loadNoFillTypes);
	setXMLBool(Xml, groupNameTag.. "#loadDefaultNoFillTypes", moFillTypes.values.loadDefaultNoFillTypes);
	setXMLBool(Xml, groupNameTag.. "#seeName", moFillTypes.values.name);
	setXMLBool(Xml, groupNameTag.. "#seeRegName", moFillTypes.values.regName);
	setXMLBool(Xml, groupNameTag.. "#seeIndex", moFillTypes.values.index);
	----------------------------------------------------------------------------------------------
	groupNameTag = (xmlNameTag.. ".module.fillTypes.defaultDeactivated");	
	local defaultNoFillType = "";
	for index, name in pairs (moFillTypes.values.defaultNoFillType) do
		if string.len(defaultNoFillType) > 0 then defaultNoFillType = defaultNoFillType.. ",".. tostring(name);else defaultNoFillType = tostring(name);end;
	end;
	setXMLString(Xml, groupNameTag.. "#name", tostring(defaultNoFillType));
	if string.len(defaultNoFillType) > 0 then defaultNoFillType = ",".. defaultNoFillType.. ",";end;
	----------------------------------------------------------------------------------------------
	function isFillAnimals(index)		
		if g_currentMission.fillTypeManager.categoryNameToFillTypes["ANIMAL"][index] ~= nil or g_currentMission.fillTypeManager.categoryNameToFillTypes["HORSE"][index] ~= nil then return true;end;
		return false;
	end;	
	groupNameTag = (xmlNameTag.. ".module.fillTypes.deactivated");
	local noFillType = "";	
	for a=1, #moFillTypes.values.fillTypes do
		if moFillTypes.values.fillTypes[a] ~= nil and not moFillTypes.values.fillTypes[a].view then
			local name = moFillTypes.values.fillTypes[a].regName;
			if not isFillAnimals(moFillTypes.values.fillTypes[a].index) then
				if not string.find(defaultNoFillType, ",".. tostring(name).. ",") then
					if string.len(noFillType) > 0 then noFillType = noFillType.. ",".. tostring(name);else noFillType = tostring(name);end;
				end;
			end;
		end;
	end;	
	setXMLString(Xml, groupNameTag.. "#name", tostring(noFillType));
	----------------------------------------------------------------------------------------------		
end;

function moFillTypesConfig.generateCmd()
	moSetGetCmd:generateCmd( {	
			modName = "MultiOverlayV4";
			cmdName = "output_fillTypesOnOff_";
			groupName = "Speziale";			
			displayName = "FillTypes On/Off Global";
			infoTxt = "Enabled or Disabled a FillType - for all Slots with MultiOverlay FillTypes";
			mouseClickAccepts = {true,false,false};
			typ = {"output_"};			
			actionCallback = moFillTypesOutput.giveOutputTable;			
		}
	)
end;

moModule:addCallbackModul( {modName="multiOverlayV4", modulCallbackName="loadConfig", callback=moFillTypesConfig.loadXml } );
moModule:addCallbackModul( {modName="multiOverlayV4", modulCallbackName="saveConfig", callback=moFillTypesConfig.saveXml } );