moModuleSetGet = {};

function moModuleSetGet:getFillLevelInformation(object)
	local fillLevelInformation = {production={}};
	local productionId = {};
	local allActive = false;
	if object ~= nil then		
		if #object.activeProductions > 0 then
			for p= 1, #object.activeProductions do
				local production = object.activeProductions[p]
				if production ~= nil then
					productionId[production.id] = true;					
				end;
			end;							
		end;
		if #object.productions > 0 then
			for p= 1, #object.productions do
				local production = object.productions[p]
				if production ~= nil then					
					local rezeptName = production.name;
					local costsPerActiveMonth = Utils.getNoNil(production.costsPerActiveMonth, 0);
					fillLevelInformation.production[#fillLevelInformation.production+1] = {status=moModuleSetGet:getProductionStatus(object, production.id), active=productionId[production.id] ~= nil, rezeptName=rezeptName, costsPerActiveMonth=costsPerActiveMonth, output={}, input={}};
					local productionOutput = fillLevelInformation.production[#fillLevelInformation.production].output;
					for o=1, #production.outputs do
						if production.outputs[o] ~= nil then
							local output = production.outputs[o];
							local fillLevel = object.storage:getFillLevel(output.type);
							local freeCapacity = object.storage:getFreeCapacity(output.type);
							local capacity = object.storage:getCapacity(output.type);							
							local amount = output.amount;							
							local directSell = object.outputFillTypeIdsDirectSell[output.type] ~= nil and object.outputFillTypeIdsDirectSell[output.type] == true;
							local directDeliver = object.outputFillTypeIdsAutoDeliver[output.type] ~= nil and object.outputFillTypeIdsAutoDeliver[output.type] == true;
							if productionOutput[output.type] == nil then
								productionOutput[output.type] = {fillLevel=fillLevel or 0, freeCapacity=freeCapacity or 0, capacity=capacity or 0, amount=amount, directDeliver=directDeliver, directSell=directSell};
							else
								freeCapacity = freeCapacity+Utils.getNoNil(productionOutput[output.type].freeCapacity, 0);
								amount = amount+Utils.getNoNil(productionOutput[output.type].amount, 0);
								capacity = capacity+Utils.getNoNil(productionOutput[output.type].capacity, 0);
								fillLevel = fillLevel+Utils.getNoNil(productionOutput[output.type].fillLevel, 0);
								productionOutput[output.type].freeCapacity = freeCapacity;
								productionOutput[output.type].capacity = capacity;
								productionOutput[output.type].amount = amount;
								productionOutput[output.type].fillLevel = fillLevel;
							end;																		
						end;
					end;
					if productionId[production.id] ~= nil then
						local productionInput = fillLevelInformation.production[#fillLevelInformation.production].input;
						for i=1, #production.inputs do
							if production.inputs[i] ~= nil then
								local input = production.inputs[i];											
								local fillLevel = object.storage:getFillLevel(input.type);											
								local capacity = object.storage:getCapacity(input.type);
								local amount = input.amount;
								if productionInput[input.type] == nil then
									productionInput[input.type] = {fillLevel=fillLevel or 0,amount=amount, capacity=capacity or 0};
								else
									fillLevel = fillLevel+Utils.getNoNil(productionInput[input.type].fillLevel, 0);
									amount = amount+Utils.getNoNil(productionInput[input.type].amount, 0);
									capacity = capacity+Utils.getNoNil(productionInput[input.type].capacity, 0);
									productionInput[input.type].fillLevel = fillLevel;
									productionInput[input.type].capacity = capacity;
									productionInput[input.type].amount = amount;
								end;
							end;
						end;
					end;
				end;
			end;
		end;
		allActive = #object.productions == #object.activeProductions;
	end;	
	return fillLevelInformation, allActive;
end;

function moModuleSetGet:getAnimalFillLevelInformation(object)
	local fillLevelInformation = {output={},input={}};
	if object ~= nil then
		local spec = object.spec_husbandryFood;
		local animalFood = g_currentMission.animalFoodSystem:getAnimalFood(spec.animalTypeIndex);
		if animalFood ~= nil then			
			for _, foodGroup in pairs(animalFood.groups) do
				local title = foodGroup.title;
				local fillLevel = 0;
				local capacity = spec.capacity;				
				local foodGroupFillTypes = {};
				for _, fillTypeIndex in pairs(foodGroup.fillTypes) do					
					foodGroupFillTypes[#foodGroupFillTypes+1] = fillTypeIndex;
					if spec.fillLevels[fillTypeIndex] ~= nil then
						fillLevel = fillLevel + spec.fillLevels[fillTypeIndex];
					end;
				end;
				local info = {
					title = string.format("%s (%d%%)", title, foodGroup.productionWeight * 100);
					fillLevel = fillLevel;
					foodGroupFillTypes = foodGroupFillTypes;
					capacity = capacity;
					ratio = 0;
				};
				if capacity > 0 then
					info.ratio = fillLevel / capacity;
				end;
				table.insert(fillLevelInformation.input, #fillLevelInformation.input+1, info);
			end;
		end;
		local conditionInfo = object:getConditionInfos();
		if conditionInfo ~= nil and #conditionInfo > 0 then
			for c=1, #conditionInfo do
				if conditionInfo[c] ~= nil then
					if conditionInfo[c].title ~= g_i18n:getText("statistic_productivity") then
						if conditionInfo[c].invertedBar ~= nil and not conditionInfo[c].invertedBar then
							local info = {
								title = conditionInfo[c].title;
								fillLevel = conditionInfo[c].value;
								--foodGroupFillTypes = nil;
								--capacity = conditionInfo[c].capacity;
								ratio = conditionInfo[c].ratio;
							};
							table.insert(fillLevelInformation.input, #fillLevelInformation.input+1, info);
						else
							local info = {
								title = conditionInfo[c].title;
								fillLevel = conditionInfo[c].value;
								--foodGroupFillTypes = nil;
								--capacity = conditionInfo[c].capacity;
								ratio = conditionInfo[c].ratio;
							};							
							table.insert(fillLevelInformation.output, #fillLevelInformation.output+1, info);
						end;
					end;
				end;
			end;
		end;
	end;
	return fillLevelInformation;
end;

function moModuleSetGet:getBunkerSiloFillLevelInformation(object)
	local fillLevelInformation = {info={},output={},input={}};
	if object ~= nil then
		local spec = object.spec_bunkerSilo;
		if spec ~= nil and spec.bunkerSilo ~= nil then
			local siloGroupFillTypes = {};
			for fillType,isAccepted in pairs(spec.bunkerSilo.acceptedFillTypes) do
				if isAccepted then
					siloGroupFillTypes[#siloGroupFillTypes+1] = fillType;							
				end;
			end;
			local info = {
				title = g_i18n:getText("info_fillLevel");
				groupFillTypes = siloGroupFillTypes;
				fillLevel = spec.bunkerSilo.fillLevel;					
			};
			table.insert(fillLevelInformation.input, #fillLevelInformation.input+1, info);
			local info = {
				fillType = spec.bunkerSilo.outputFillType;
				fillLevel = spec.bunkerSilo.fillLevel;					
			};
			table.insert(fillLevelInformation.output, #fillLevelInformation.output+1, info);
			local info = {
				compactedPercent = spec.bunkerSilo.compactedPercent;
				compactedFillLevel = spec.bunkerSilo.compactedFillLevel;
				fermentingPercent = spec.bunkerSilo.fermentingPercent;
				state = spec.bunkerSilo.state;
			};
			table.insert(fillLevelInformation.info, #fillLevelInformation.info+1, info);
		end;
	end;
	return fillLevelInformation;
end;

function moModuleSetGet:searchPallets(startWorldX, startWorldZ)
	
end;

function moModuleSetGet:getProductionStatus(object, productionId)
	return object.productionsIdToObj[productionId].status;
end

function moModuleSetGet:getProductionPoints()
	local playerFarmId = g_currentMission.player.farmId;
	if playerFarmId == 0 then return nil;end;
	if g_currentMission.productionChainManager == nil or InGameMenuProductionFrame.chainManager == nil then return nil;end;
	return g_currentMission.productionChainManager:getProductionPointsForFarmId(playerFarmId);
end;

function moModuleSetGet:getSelectedProduction()
	local productionPoint = moModuleSetGet:getProductionPoints()[g_currentMission.inGameMenu.pageProduction.productionList:getSelectedSection()];
	local production = productionPoint.productions[g_currentMission.inGameMenu.pageProduction.productionList:getSelectedIndexInSection()];
	return production, productionPoint;
end;

function moModuleSetGet:setSelectedProductionPoint(productionPoint, production)
	local productionList = moModuleSetGet:getProductionPoints();
	if productionList ~= nil and #productionList > 0 then
		for index, listProdPoint in ipairs(productionList) do
			if listProdPoint == productionPoint then
				g_currentMission.inGameMenu.pageProduction.productionList:setSelectedItem(index, production or 1);
				break;
			end;
		end;
	end;
end;